@@ -156,11 +156,13 @@ class VectorAcousticWaveDataset2D(VectorAcousticWaveDataset):
                 ax.set_xlabel("time (s)")
                 ax.set_ylabel("Amplitude")
                 ax.set_ylim([np.min(data), np.max(data)])
+                ax.grid("on")
             else:
                 ax[i].legend(["Abscissa", "Ordinate"])
                 ax[i].set_title(str(self.interrogators[i]))
                 ax[i].set_xlabel("time (s)")
                 ax[i].set_ylabel("Amplitude")
+                ax[i].grid("on")
         if len(self.interrogators) > 1:
             for i in range(len(self.interrogators)):
                 ax[i].set_ylim([np.min(y_lims), np.max(y_lims)])
